/* This file was generated by syncqt. */
#ifndef QT_QTPURCHASING_VERSION_H
#define QT_QTPURCHASING_VERSION_H

#define QTPURCHASING_VERSION_STR "5.15.12"

#define QTPURCHASING_VERSION 0x050F0C

#endif // QT_QTPURCHASING_VERSION_H
